@@ -3,7 +3,7 @@
 // Use of this source code is governed by a MIT license that can be found in the
 // LICENSE file.
 /*******************************************************************************/
-#include <stdlib.h>
+#include <R.h>
 #include "inform/integration.h"
 
 void r_integration_evidence_(int *series, int *l, int *n, int *b,
@@ -17,7 +17,7 @@ void r_integration_evidence_(int *series, int *l, int *n, int *b,
 void r_integration_evidence_parts_(int *series, int *l, int *n, int *b,
 				   int *parts, int *nparts, double *evidence, int *err) {
   inform_error ierr = INFORM_SUCCESS;
-  size_t *st_parts = malloc((*l) * sizeof(size_t));
+  size_t *st_parts = (size_t*) R_alloc(*l, sizeof(size_t));
 
   for (size_t i = 0; i < *l; ++i) {
     st_parts[i] = parts[i];
@@ -25,6 +25,5 @@ void r_integration_evidence_parts_(int *series, int *l, int *n, int *b,
 
   inform_integration_evidence_part(series, *l, *n, b, st_parts, *nparts, evidence, &ierr);
   *err = ierr;
-  free(st_parts);
 }
 
